`Problem Set: assignment1`

# The Commuter

A logic puzzle by Brandon Bennett

Your problem is to use propositional logic to represent the following example of reasoning, and use the Prover9 theorem prover to prove that the reasoning is valid.

Use the following template file to create your Prover9 encoding of the problem: `commuter.p9`

Marks: There are two marks for each sentence, making a total of 18 marks.

Outline: Getting to work is a common everyday problem. Using propositional logic, we can represent the situation and reason about how to get there. The propositional logic within sentences can be expressed in a variety of ways. You need to be clear about the meaining of the logical operators to check that your representations fit the meanings of the sentences.

## Problem Statement

A1 | To get to work I either go by foot or by cycling or by bus.
A2 | If it rains when I'm outside without my hat, my hair gets wet.
A3 | If I'm wearing my hat or have wet hair, I can't hear well.
A4 | If I'm outside when it is raining and I can't hear well, I get splashed by cars.
A5 | When I go to work on foot or on my bike I am outside.
A6 | It always rains when it is cloudy and I don't cycle when it rains.
A7 | I always wear my hat when I cycle, but not any other time.
A8 | When going to work, I make sure I never get splashed by cars.
Goal | If it is cloudy when I am going to work, I go by bus.

### Non-Logical Vocabulary

Propositions: `GoToWork`, `Foot`, `Cycle`, `Bus`, `Raining`, `Cloudy`, `Outside`, `Hat`, `HairWet`, `HearWell`, `SplashedByCars`